@@ -99,7 +99,8 @@ $worksheet->write( 'B9', 'http://www.perl.com/' );
 # Images
 #
 $worksheet->write( 'A10', "Images" );
-$worksheet->insert_image( 'B10', 'republic.png', 16, 8 );
+$worksheet->insert_image( 'B10', 'republic.png',
+                                 { x_offset => 16, y_offset => 8 } );
 
 
 #######################################################################
