@@ -5,7 +5,7 @@
 # Example of how to use Excel::Writer::XLSX to write a hyperlink in a
 # merged cell.
 #
-# reverse(''), September 2002, John McNamara, jmcnamara@cpan.org
+# reverse ('(c)'), September 2002, John McNamara, jmcnamara@cpan.org
 #
 
 use strict;
@@ -42,3 +42,6 @@ $worksheet->merge_range( 'B4:D4', 'http://www.perl.com', $format );
 $worksheet->merge_range( 'B7:D8', 'http://www.perl.com', $format );
 
 
+$workbook->close();
+
+__END__
