@@ -27,6 +27,7 @@ my $worksheet9  = $workbook->add_worksheet();
 my $worksheet10 = $workbook->add_worksheet();
 my $worksheet11 = $workbook->add_worksheet();
 my $worksheet12 = $workbook->add_worksheet();
+my $worksheet13 = $workbook->add_worksheet();
 
 my $currency_format = $workbook->add_format( num_format => '$#,##0' );
 
@@ -315,7 +316,7 @@ $worksheet11->add_table(
 #
 # Example 12.
 #
-$caption = 'Table with column formats.';
+$caption = 'Table with no Excel style.';
 
 # Set the columns widths.
 $worksheet12->set_column( 'B:G', 12 );
@@ -325,6 +326,41 @@ $worksheet12->write( 'B1', $caption );
 
 # Add a table to the worksheet.
 $worksheet12->add_table(
+    'B3:G8',
+    {
+        data      => $data,
+        style     => 'None',
+        total_row => 1,
+        columns   => [
+            { header => 'Product',   total_string   => 'Totals' },
+            { header => 'Quarter 1', total_function => 'sum' },
+            { header => 'Quarter 2', total_function => 'sum' },
+            { header => 'Quarter 3', total_function => 'sum' },
+            { header => 'Quarter 4', total_function => 'sum' },
+            {
+                header         => 'Year',
+                formula        => '=SUM(Table12[@[Quarter 1]:[Quarter 4]])',
+                total_function => 'sum'
+            },
+        ]
+    }
+);
+
+
+###############################################################################
+#
+# Example 13.
+#
+$caption = 'Table with column formats.';
+
+# Set the columns widths.
+$worksheet13->set_column( 'B:G', 12 );
+
+# Write the caption.
+$worksheet13->write( 'B1', $caption );
+
+# Add a table to the worksheet.
+$worksheet13->add_table(
     'B3:G8',
     {
         data      => $data,
@@ -353,7 +389,7 @@ $worksheet12->add_table(
             },
             {
                 header         => 'Year',
-                formula        => '=SUM(Table12[@[Quarter 1]:[Quarter 4]])',
+                formula        => '=SUM(Table13[@[Quarter 1]:[Quarter 4]])',
                 total_function => 'sum',
                 format         => $currency_format,
             },
