@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 
 ###############################################################################
@@ -253,19 +253,21 @@ sub _write_table_style_info {
     my $self  = shift;
     my $props = $self->{_properties};
 
+    my @attributes          = ();
     my $name                = $props->{_style};
     my $show_first_column   = $props->{_show_first_col};
     my $show_last_column    = $props->{_show_last_col};
     my $show_row_stripes    = $props->{_show_row_stripes};
     my $show_column_stripes = $props->{_show_col_stripes};
 
-    my @attributes = (
-        'name'              => $name,
-        'showFirstColumn'   => $show_first_column,
-        'showLastColumn'    => $show_last_column,
-        'showRowStripes'    => $show_row_stripes,
-        'showColumnStripes' => $show_column_stripes,
-    );
+    if ( $name && $name ne '' && $name ne 'None' ) {
+        push @attributes, ( 'name' => $name );
+    }
+
+    push @attributes, ( 'showFirstColumn'   => $show_first_column );
+    push @attributes, ( 'showLastColumn'    => $show_last_column );
+    push @attributes, ( 'showRowStripes'    => $show_row_stripes );
+    push @attributes, ( 'showColumnStripes' => $show_column_stripes );
 
     $self->xml_empty_tag( 'tableStyleInfo', @attributes );
 }
