@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 
 ###############################################################################
@@ -655,6 +655,7 @@ sub _write_image_shape {
     my $position = $image_data->[3];
     my $x_dpi    = $image_data->[4];
     my $y_dpi    = $image_data->[5];
+    my $ref_id   = $image_data->[6];
 
     # Scale the height/width by the resolution, relative to 72dpi.
     $width  = $width  * 72 / $x_dpi;
@@ -685,7 +686,7 @@ sub _write_image_shape {
     $self->xml_start_tag( 'v:shape', @attributes );
 
     # Write the v:imagedata element.
-    $self->_write_imagedata( $index, $name );
+    $self->_write_imagedata( $ref_id, $name );
 
     # Write the o:lock element.
     $self->_write_rotation_lock();
